@@ -78,16 +78,14 @@ int exist_file(const char *filename);
 int is_regular_file(const char *filename);
 astr agetcwd(void);
 astr get_home_dir(void);
-int expand_path(const char *path, const char *cwdir, astr dir, astr fname);
+int expand_path(const char *path, astr dir, astr fname);
 astr compact_path(const char *path);
-astr get_current_dir(int interactive);
-void open_file(char *path, size_t lineno);
 void read_from_disk(const char *filename);
 int find_file(const char *filename);
 Completion *make_buffer_completion(void);
 int check_modified_buffer(Buffer *bp);
 void kill_buffer(Buffer *kill_bp);
-void zile_exit(int exitcode);
+void zile_exit(void);
 
 /* funcs.c ---------------------------------------------------------------- */
 int cancel(void);
