@@ -1,6 +1,6 @@
-/* Dynamically allocated strings
+/* strrstr implementation
    Copyright (c) Kent Irwin (kent.irwin@nist.gov).
-   Copyright (c) 2004 Reuben Thomas.
+   Copyright (c) 2004, 2007 Reuben Thomas.
    All rights reserved.
 
    This file is part of Zile.
@@ -20,18 +20,20 @@
    Software Foundation, Fifth Floor, 51 Franklin Street, Boston, MA
    02111-1301, USA.  */
 
-/*	$Id: strrstr.c,v 1.5 2005/07/11 06:10:26 rrt Exp $	*/
+/*	$Id: strrstr.c,v 1.8 2007/05/03 15:44:29 rrt Exp $	*/
 
 #include "config.h"
 
 #ifndef HAVE_STRRSTR
 
+#include <stddef.h>
 #include <string.h>
 
 char *strrstr(const char *s, const char *t);
 
-char *strrstr(const char *s, const char *t) {
-  int i, j, slen = strlen(s), tlen = strlen(t);
+char *strrstr(const char *s, const char *t)
+{
+  size_t i, j, slen = strlen(s), tlen = strlen(t);
 
   if (slen < tlen)
     return NULL;
